summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorDavid Lönnhager <david.l@mullvad.net>2026-04-16 14:03:45 +0200
committerDavid Lönnhager <david.l@mullvad.net>2026-04-20 13:58:47 +0200
commit23da003c9c0ebdac8b700200ecf98561f4958eb7 (patch)
tree1668a2ffb23b7de7bf4315cebcdc50b6f80cca89
parent819de86a77c006a180d41707d14fa1be6ef87bb3 (diff)
downloadmullvadvpn-23da003c9c0ebdac8b700200ecf98561f4958eb7.tar.xz
mullvadvpn-23da003c9c0ebdac8b700200ecf98561f4958eb7.zip
Rename incorrect references to cgroup2
-rw-r--r--talpid-cgroup/src/v1.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/talpid-cgroup/src/v1.rs b/talpid-cgroup/src/v1.rs
index 08a369735d..a7d8922c0d 100644
--- a/talpid-cgroup/src/v1.rs
+++ b/talpid-cgroup/src/v1.rs
@@ -24,7 +24,7 @@ pub struct CGroup1 {
/// Absolute path of the cgroup, e.g. `/sys/fs/cgroup/net_cls/foobar`
path: PathBuf,
- /// `cgroup.procs` is used to add and list PIDs in the cgroup2.
+ /// `cgroup.procs` is used to add and list PIDs in the cgroup.
procs: File,
}
@@ -89,7 +89,7 @@ impl CGroup1 {
Self::open(child_path)
}
/// Try to clone the cgroup2 handle.
///
/// This is fallible because cloning file descriptors can fail.
pub fn try_clone(&self) -> Result<Self, super::Error> {
@@ -102,7 +102,7 @@ impl CGroup1 {
})
}
/// Assign a process to this cgroup2.
pub fn add_pid(&self, pid: Pid) -> Result<(), super::Error> {
// Format the PID as a string
let mut pid_buf = [0u8; 16];
@@ -111,12 +111,12 @@ impl CGroup1 {
// Write PID to `cgroup.procs`.
nix::unistd::write(&self.procs, pid_str.to_bytes())
- .with_context(|| anyhow!("Failed to add process {pid} to cgroup2"))?;
+ .with_context(|| anyhow!("Failed to add process {pid} to cgroup"))?;
Ok(())
}
/// List all PIDs in this cgroup2.
pub fn list_pids(&mut self) -> Result<Vec<pid_t>, super::Error> {
let mut file = &self.procs;
let mut pids = String::new();
@@ -89,7 +89,7 @@ impl CGroup1 {
Self::open(child_path)
}
- /// Try to clone the cgroup2 handle.
+ /// Try to clone the cgroup handle.
///
/// This is fallible because cloning file descriptors can fail.
@@ -102,7 +102,7 @@ impl CGroup1 {
})
}
- /// Assign a process to this cgroup2.
+ /// Assign a process to this cgroup.
pub fn add_pid(&self, pid: Pid) -> Result<(), super::Error> {
// Format the PID as a string
@@ -111,12 +111,12 @@ impl CGroup1 {
Ok(())
}
- /// List all PIDs in this cgroup2.
+ /// List all PIDs in this cgroup.
pub fn list_pids(&mut self) -> Result<Vec<pid_t>, super::Error> {
let mut file = &self.procs;